@@ -28,10 +28,16 @@ def hashivault_argspec():
 
 def hashivault_init(argument_spec, supports_check_mode=False, required_if=None, required_together=None,
                     required_one_of=None, mutually_exclusive=None):
-    return AnsibleModule(argument_spec=argument_spec, supports_check_mode=supports_check_mode,
-                         required_if=required_if, required_together=required_together, required_one_of=required_one_of,
-                         mutually_exclusive=mutually_exclusive)
-
+    module = AnsibleModule(argument_spec=argument_spec, supports_check_mode=supports_check_mode,
+                           required_if=required_if, required_together=required_together,
+                           required_one_of=required_one_of, mutually_exclusive=mutually_exclusive)
+    module.no_log_values.discard("0")
+    module.no_log_values.discard(0)
+    module.no_log_values.discard("1")
+    module.no_log_values.discard(1)
+    module.no_log_values.discard(True)
+    module.no_log_values.discard(False)
+    return module
 
 def get_ec2_iam_role():
     request = requests.get(url='http://169.254.169.254/latest/meta-data/iam/security-credentials/')
